@@ -1,5 +1,8 @@
 from __future__ import print_function
 
+import os
+
+from compas.robots import RobotModel
 from compas.utilities import await_callback
 from roslibpy import Message
 from roslibpy import Ros
@@ -7,6 +10,7 @@ from roslibpy.actionlib import ActionClient
 from roslibpy.actionlib import Goal
 
 from compas_fab.backends.ros.exceptions import RosError
+from compas_fab.backends.ros.fileserver_loader import RosFileServerLoader
 from compas_fab.backends.ros.messages import ExecuteTrajectoryFeedback
 from compas_fab.backends.ros.messages import ExecuteTrajectoryGoal
 from compas_fab.backends.ros.messages import ExecuteTrajectoryResult
@@ -21,6 +25,8 @@ from compas_fab.backends.ros.messages import RobotTrajectory
 from compas_fab.backends.ros.messages import Time
 from compas_fab.backends.ros.planner_backend_moveit import MoveItPlanner
 from compas_fab.backends.tasks import CancellableFutureResult
+from compas_fab.robots import Robot
+from compas_fab.robots import RobotSemantics
 
 __all__ = [
     'RosClient',
@@ -110,6 +116,59 @@ class RosClient(Ros):
 
         self.close()
 
+    def load_robot(self, load_geometry=False, urdf_param_name='/robot_description', srdf_param_name='/robot_description_semantic', precision=None, local_cache_directory=None):
+        """Load an entire robot instance -including model and semantics- directly from ROS.
+
+        Parameters
+        ----------
+        load_geometry : bool, optional
+            ``True`` to load the robot's geometry, otherwise ``False`` to load only the model and semantics.
+        urdf_param_name : str, optional
+            Parameter name where the URDF is defined. If not defined, it will default to ``/robot_description``.
+        srdf_param_name : str, optional
+            Parameter name where the SRDF is defined. If not defined, it will default to ``/robot_description_semantic``.
+        precision : float
+            Defines precision for importing/loading meshes. Defaults to ``compas.PRECISION``.
+        local_cache_directory : str, optional
+            Directory where the robot description (URDF, SRDF and meshes) are stored.
+            This differs from the directory taken as parameter by the :class:`RosFileServerLoader`
+            in that it points directly to the specific robot package, not to a global workspace storage
+            for all robots. If not assigned, the robot will not be cached locally.
+
+        Examples
+        --------
+
+        >>> from compas_fab.backends import RosClient
+        >>> with RosClient() as client:
+        ...     robot = client.load_robot()
+        ...     print(robot.name)
+        ur5
+        """
+        robot_name = None
+        use_local_cache = False
+
+        if local_cache_directory is not None:
+            use_local_cache = True
+            path_parts = local_cache_directory.strip(os.path.sep).split(os.path.sep)
+            path_parts, robot_name = path_parts[:-1], path_parts[-1]
+            local_cache_directory = os.path.sep.join(path_parts)
+
+        loader = RosFileServerLoader(self, use_local_cache, local_cache_directory, precision)
+
+        if robot_name:
+            loader.robot_name = robot_name
+
+        urdf = loader.load_urdf(urdf_param_name)
+        srdf = loader.load_srdf(srdf_param_name)
+
+        model = RobotModel.from_urdf_string(urdf)
+        semantics = RobotSemantics.from_srdf_string(srdf, model)
+
+        if load_geometry:
+            model.load_geometry(loader)
+
+        return Robot(model, semantics=semantics, client=self)
+
     def inverse_kinematics(self, frame, base_link, group,
                            joint_names, joint_positions, avoid_collisions=True,
                            constraints=None, attempts=8,
