@@ -265,6 +265,10 @@ class PlanningScene(object):
             The planning group to which we want to attach the mesh to. Defaults
             to the robot's main planning group.
 
+        Returns
+        -------
+        None
+
         Examples
         --------
         >>> scene = PlanningScene(robot)
@@ -282,7 +286,7 @@ class PlanningScene(object):
 
         >>> # check if it's really gone
         >>> planning_scene = robot.client.get_planning_scene()
-        >>> objects = [c.object.id for c in planning_scene.robot_state.attached_collision_objects]
+        >>> objects = [c.object['id'] for c in planning_scene.robot_state.attached_collision_objects]
         >>> 'tip' in objects
         False
         """
@@ -296,3 +300,17 @@ class PlanningScene(object):
         touch_links = [ee_link_name]
         acm = AttachedCollisionMesh(collision_mesh, ee_link_name, touch_links)
         self.add_attached_collision_mesh(acm)
+
+    def add_attached_tool(self):
+        """Adds the robot's attached tool to the planning scene if set.
+        """
+        self.ensure_client()
+        if self.robot.attached_tool:
+            self.add_attached_collision_mesh(self.robot.attached_tool.attached_collision_mesh)
+
+    def remove_attached_tool(self):
+        """Removes the robot's attached tool from the planning scene.
+        """
+        self.ensure_client()
+        if self.robot.attached_tool:
+            self.remove_attached_collision_mesh(self.robot.attached_tool.name)
